@@ -43,6 +43,21 @@ __wb = WorldBankData()
 )
 
 
+def __get_dac_codes() -> dict:
+    """Return dac codes dictionary"""
+    file = PATHS.imported_data + r"/oecd_codes.csv"
+
+    return pd.read_csv(file, na_values=None, index_col="code")["iso_code"].to_dict()
+
+
+def __read_flourish_geometries() -> dict:
+    """Reads flourish geometries"""
+    file = f"{PATHS.imported_data}/flourish_geometries.csv"
+    return pd.read_csv(file, na_values=None, index_col="3-letter ISO code")[
+        "geometry"
+    ].to_dict()
+
+
 def update_dictionaries() -> None:
     """Updates dictionaries"""
     __wb.update()
@@ -111,12 +126,25 @@ eu27 = Dict(
     }
 )
 
-g7 = Dict({x: convert(x, src="ISO3", to="name_short") for x in ["FRA", "DEU", "ITA", "GBR", "USA", "JPN", "CAN"]})
+g7 = Dict(
+    {
+        x: convert(x, src="ISO3", to="name_short")
+        for x in ["FRA", "DEU", "ITA", "GBR", "USA", "JPN", "CAN"]
+    }
+)
 
 income_levels = Dict(__get_income_levels())
 
-life_expectancy = Dict(__wb.get_data("SP.DYN.LE00.IN").set_index("iso_code")["value"].to_dict())
+life_expectancy = Dict(
+    __wb.get_data("SP.DYN.LE00.IN").set_index("iso_code")["value"].to_dict()
+)
 
-population_density = Dict(__wb.get_data("EN.POP.DNST").set_index("iso_code")["value"].to_dict())
+population_density = Dict(
+    __wb.get_data("EN.POP.DNST").set_index("iso_code")["value"].to_dict()
+)
 
 population = Dict(__wb.get_data("SP.POP.TOTL").set_index("iso_code")["value"].to_dict())
+
+dac_codes = Dict(__get_dac_codes())
+
+flourish_geometries = Dict(__read_flourish_geometries())
\ No newline at end of file
